@@ -3,12 +3,12 @@ C Output from Public domain Ratfor, version 1.01
      * ry, rj)
       implicit double precision (a-h,o-z)
       integer p, npair(p,p)
-      double precision xx(n,p), dmat(p,p), aadmat(p,p), madmat(p,p), x(1
-     *), y(1), rx(1), ry(1), rj(1), maxad
+      double precision xx(n,p), dmat(p,p), aadmat(p,p), madmat(p,p), x(n
+     *), y(n), rx(n), ry(n), rj(n), maxad
       do23000 i=1, p 
       np=0
       do23002 k=1, n 
-      if(xx(k,i) .lt. 1e30)then
+      if(xx(k,i) .lt. 1d49)then
       np = np + 1
       endif
 23002 continue
@@ -19,7 +19,7 @@ C Output from Public domain Ratfor, version 1.01
       do23008 k=1,n 
       xk = xx(k,i)
       yk = xx(k,j)
-      if(xk .lt. 1e30 .and. yk .lt. 1e30)then
+      if(xk .lt. 1d49 .and. yk .lt. 1d49)then
       m = m + 1
       x(m) = xk
       y(m) = yk
@@ -33,7 +33,7 @@ C Output from Public domain Ratfor, version 1.01
       aadmat(i,j) = aad
       madmat(i,j) = maxad
       else
-      dmat(i,j) = 1e30
+      dmat(i,j) = 1d50
       endif
 23006 continue
 23007 continue
@@ -54,7 +54,7 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine hoeff(x, y, n, d, aad, maxad, rx, ry, rj)
       implicit double precision (a-h,o-z)
-      double precision x(1), y(1), rx(1), ry(1), rj(1), maxad
+      double precision x(n), y(n), rx(n), ry(n), rj(n), maxad
       call jrank(x, y, n, rx, ry, rj)
       q = 0d0
       r = 0d0
@@ -80,7 +80,9 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine jrank(x, y, n, rx, ry, r)
-      double precision x(1), y(1), rx(1), ry(1), r(1), cx, cy
+      integer n
+      double precision x(n), y(n), rx(n), ry(n), r(n), cx, cy, ri, rix, 
+     *riy, xi, yi
       do23020 i=1,n 
       xi = x(i)
       yi = y(i)
